@@ -1,4 +1,4 @@
-__version__ = '0.0.39'
+__version__ = '0.0.40'
 
 DB_VERSION = 1
 
@@ -688,7 +688,7 @@ class YEDB():
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
 
-    def set(self, key, value, flush=False, stime=None):
+    def set(self, key, value, flush=False, stime=None, _ignore_schema=False):
         """
         Set key to value
 
@@ -726,7 +726,8 @@ class YEDB():
                             return
                     except KeyError:
                         pass
-                self.validate_schema(key, value)
+                if not _ignore_schema:
+                    self.validate_schema(key, value)
                 self._write(key_file,
                             self._dump_value(value, stime=stime),
                             flush=flush or self.auto_flush)
@@ -1310,16 +1311,17 @@ class YEDB():
         """
         return self.get_subkeys(key=key, ignore_broken=True, hidden=True)
 
-    def load_keys(self, data):
+    def load_keys(self, data, use_schema=False):
         """
         Loads keys
 
         Args:
             data: list or generator of key/value pairs (lists or tuples)
+            use_schema: use schema validation (default: False)
         """
         with self.lock:
             for d in data:
-                self.set(key=d[0], value=d[1])
+                self.set(key=d[0], value=d[1], _ignore_schema=not use_schema)
 
 
 class KeyDict:
